==> lombok-annotations-1.18.14-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="1.18.14"></a>

## [1.18.14](https://github.com/lars-sh/lombok-annotations/compare/7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4...6f353640b02e9481c38be1c36a2c94009f230ab5) (2020-10-09)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.14/jar)

* Update lombok to version 1.18.14

<a name="1.18.12"></a>

## [1.18.12](https://github.com/lars-sh/lombok-annotations/compare/470ef0cb483fe7f216c12d391b7c9cc4af363717...7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4) (2020-02-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.12/jar)

* Update lombok to version 1.18.12

<a name="1.18.10"></a>

## [1.18.10](https://github.com/lars-sh/lombok-annotations/compare/86fb835baaed0f81c0fb96506144bf9456c4d96b...470ef0cb483fe7f216c12d391b7c9cc4af363717) (2019-09-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.10/jar)

* Update lombok to version 1.18.10

<a name="1.18.8"></a>

## [1.18.8](https://github.com/lars-sh/lombok-annotations/compare/646ab1c032f957dd9cd3403a3555ad2de1cda124...86fb835baaed0f81c0fb96506144bf9456c4d96b) (2019-05-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.8/jar)

* Update lombok to version 1.18.8

<a name="1.18.6"></a>

## [1.18.6](https://github.com/lars-sh/lombok-annotations/compare/8f7f0f67c7c9780858d9308c259aa4489dfc71af...646ab1c032f957dd9cd3403a3555ad2de1cda124) (2019-05-05)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.6/jar)

* Update lombok to version 1.18.6

<a name="1.18.4"></a>

## [1.18.4](https://github.com/lars-sh/lombok-annotations/commit/8f7f0f67c7c9780858d9308c259aa4489dfc71af) (2018-11-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.4/jar)

* Initial release

==> lombok-annotations-1.18.20-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="1.18.20"></a>

## [1.18.20](https://github.com/lars-sh/lombok-annotations/compare/f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0...0e816fe678b96a0ad4339a340c74891327c9c358) (2021-04-02)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.20/jar)

* Update lombok to version 1.18.20

<a name="1.18.16"></a>

## [1.18.16](https://github.com/lars-sh/lombok-annotations/compare/6f353640b02e9481c38be1c36a2c94009f230ab5...f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0) (2020-10-17)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.16/jar)

* Update lombok to version 1.18.16

<a name="1.18.14"></a>

## [1.18.14](https://github.com/lars-sh/lombok-annotations/compare/7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4...6f353640b02e9481c38be1c36a2c94009f230ab5) (2020-10-09)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.14/jar)

* Update lombok to version 1.18.14

<a name="1.18.12"></a>

## [1.18.12](https://github.com/lars-sh/lombok-annotations/compare/470ef0cb483fe7f216c12d391b7c9cc4af363717...7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4) (2020-02-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.12/jar)

* Update lombok to version 1.18.12

<a name="1.18.10"></a>

## [1.18.10](https://github.com/lars-sh/lombok-annotations/compare/86fb835baaed0f81c0fb96506144bf9456c4d96b...470ef0cb483fe7f216c12d391b7c9cc4af363717) (2019-09-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.10/jar)

* Update lombok to version 1.18.10

<a name="1.18.8"></a>

## [1.18.8](https://github.com/lars-sh/lombok-annotations/compare/646ab1c032f957dd9cd3403a3555ad2de1cda124...86fb835baaed0f81c0fb96506144bf9456c4d96b) (2019-05-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.8/jar)

* Update lombok to version 1.18.8

<a name="1.18.6"></a>

## [1.18.6](https://github.com/lars-sh/lombok-annotations/compare/8f7f0f67c7c9780858d9308c259aa4489dfc71af...646ab1c032f957dd9cd3403a3555ad2de1cda124) (2019-05-05)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.6/jar)

* Update lombok to version 1.18.6

<a name="1.18.4"></a>

## [1.18.4](https://github.com/lars-sh/lombok-annotations/commit/8f7f0f67c7c9780858d9308c259aa4489dfc71af) (2018-11-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.4/jar)

* Initial release
